@@ -123,8 +123,6 @@ def probe(*devices):
 
 def list_(device, unit=None):
     '''
-    partition.list device unit
-
     Prints partition information of given <device>
 
     CLI Examples:
@@ -191,8 +189,6 @@ def list_(device, unit=None):
 
 def align_check(device, part_type, partition):
     '''
-    partition.align_check device part_type partition
-
     Check if partition satisfies the alignment constraint of part_type.
     Type must be "minimal" or "optimal".
 
@@ -225,8 +221,6 @@ def align_check(device, part_type, partition):
 
 def check(device, minor):
     '''
-    partition.check device minor
-
     Checks if the file system on partition <minor> has any errors.
 
     CLI Example:
@@ -251,11 +245,9 @@ def check(device, minor):
 
 def cp(device, from_minor, to_minor):  # pylint: disable=C0103
     '''
-    partition.check device from_minor to_minor
-
     Copies the file system on the partition <from-minor> to partition
-        <to-minor>, deleting the original contents of the destination
-        partition.
+    <to-minor>, deleting the original contents of the destination
+    partition.
 
     CLI Example:
 
@@ -280,8 +272,6 @@ def cp(device, from_minor, to_minor):  # pylint: disable=C0103
 
 def get_id(device, minor):
     '''
-    partition.get_id
-
     Prints the system ID for the partition. Some typical values are::
 
          b: FAT32 (vfat)
@@ -313,8 +303,6 @@ def get_id(device, minor):
 
 def set_id(device, minor, system_id):
     '''
-    partition.set_id
-
     Sets the system ID for the partition. Some typical values are::
 
          b: FAT32 (vfat)
@@ -372,12 +360,9 @@ def system_types():
 
 def mkfs(device, fs_type):
     '''
-    partition.mkfs device fs_type
-
     Makes a file system <fs_type> on partition <device>, destroying all data
-        that resides on that partition. <fs_type> must be one of "ext2",
-        "fat32", "fat16", "linux-swap" or "reiserfs" (if libreiserfs is
-        installed)
+    that resides on that partition. <fs_type> must be one of "ext2", "fat32",
+    "fat16", "linux-swap" or "reiserfs" (if libreiserfs is installed)
 
     CLI Example:
 
@@ -401,9 +386,8 @@ def mkfs(device, fs_type):
 
 def mklabel(device, label_type):
     '''
-    partition.mklabel device label_type
-
     Create a new disklabel (partition table) of label_type.
+
     Type should be one of "aix", "amiga", "bsd", "dvh", "gpt", "loop", "mac",
     "msdos", "pc98", or "sun".
 
@@ -428,11 +412,9 @@ def mklabel(device, label_type):
 
 def mkpart(device, part_type, fs_type=None, start=None, end=None):
     '''
-    partition.mkpart device part_type fs_type start end
-
     Make a part_type partition for filesystem fs_type, beginning at start and
-        ending at end (by default in megabytes).  part_type should be one of
-        "primary", "logical", or "extended".
+    ending at end (by default in megabytes).  part_type should be one of
+    "primary", "logical", or "extended".
 
     CLI Examples:
 
@@ -477,13 +459,12 @@ def mkpart(device, part_type, fs_type=None, start=None, end=None):
 
 def mkpartfs(device, part_type, fs_type, start, end):
     '''
-    partition.mkpartfs device part_type fs_type start end
-
     Make a <part_type> partition with a new filesystem of <fs_type>, beginning
-        at <start> and ending at <end> (by default in megabytes).  <part_type>
-        should be one of "primary", "logical", or "extended". <fs_type> must be
-        one of "ext2", "fat32", "fat16", "linux-swap" or "reiserfs" (if
-        libreiserfs is installed)
+    at <start> and ending at <end> (by default in megabytes).
+
+    <part_type> should be one of "primary", "logical", or "extended". <fs_type>
+    must be one of "ext2", "fat32", "fat16", "linux-swap" or "reiserfs" (if
+    libreiserfs is installed)
 
     CLI Example:
 
@@ -516,10 +497,8 @@ def mkpartfs(device, part_type, fs_type, start, end):
 
 def name(device, partition, name):
     '''
-    partition.name device partition name
-
-    Set the name of partition to name. This option works only on Mac, PC98,
-        and GPT disklabels. The name can be placed in quotes, if necessary.
+    Set the name of partition to name. This option works only on Mac, PC98, and
+    GPT disklabels. The name can be placed in quotes, if necessary.
 
     CLI Example:
 
@@ -550,11 +529,9 @@ def name(device, partition, name):
 
 def rescue(device, start, end):
     '''
-    partition.rescue device start end
-
     Rescue a lost partition that was located somewhere between start and end.
-        If a partition is found, parted will ask if you want to create an
-        entry for it in the partition table.
+    If a partition is found, parted will ask if you want to create an
+    entry for it in the partition table.
 
     CLI Example:
 
@@ -573,13 +550,12 @@ def rescue(device, start, end):
 
 def resize(device, minor, start, end):
     '''
-    partition.resize device minor, start, end
+    Resizes the partition with number <minor>.
 
-    Resizes the partition with number <minor>. The partition will start <start>
-        from the beginning of the disk, and end <end> from the beginning of the
-        disk. resize never changes the minor number. Extended partitions can be
-        resized, so long as the new extended partition completely contains all
-        logical partitions.
+    The partition will start <start> from the beginning of the disk, and end
+    <end> from the beginning of the disk. resize never changes the minor number.
+    Extended partitions can be resized, so long as the new extended partition
+    completely contains all logical partitions.
 
     CLI Example:
 
@@ -609,8 +585,6 @@ def resize(device, minor, start, end):
 
 def rm(device, minor):  # pylint: disable=C0103
     '''
-    partition.rm device minor
-
     Removes the partition with number <minor>.
 
     CLI Example:
@@ -635,11 +609,10 @@ def rm(device, minor):  # pylint: disable=C0103
 
 def set_(device, minor, flag, state):
     '''
-    partition.set device  minor flag state
+    Changes a flag on the partition with number <minor>.
 
-    Changes a flag on the partition with number <minor>. A flag can be either
-        "on" or "off". Some or all of these flags will be available, depending
-        on what disk label you are using.
+    A flag can be either "on" or "off". Some or all of these flags will be
+    available, depending on what disk label you are using.
 
     CLI Example:
 
@@ -670,8 +643,6 @@ def set_(device, minor, flag, state):
 
 def toggle(device, partition, flag):
     '''
-    partition.toggle device partition flag
-
     Toggle the state of <flag> on <partition>
 
     CLI Example:
@@ -700,8 +671,6 @@ def toggle(device, partition, flag):
 
 def exists(device=''):
     '''
-    partition.exists device
-
     Check to see if the partition exists
 
     CLI Example:
